/**
  *  \file client/widgets/partcount.cc
  *  \brief Ship Build Screen Part Count Selection/Display
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "client/widgets/partcount.h"
#include "client/widgets/partstorage.h"  // cm_XXX
#include "cpluslib/format.h"
#include "ui/layout.h"
#include "ui/uiglobal.h"
#include "util/nls.h"

/***************************** WPartCountInfo ****************************/

WPartCountInfo::WPartCountInfo(bool torps)
    : torps(torps), want(0), max(0)
{ }

void
WPartCountInfo::drawContent(GfxCanvas& can)
{
    const char* fmt = torps ? _("Max. launchers on ship: %d") : _("Max. beams on ship: %d");
    int x = getExtent().x, y = getExtent().y, wi = getExtent().w;

    GfxContext ctx;
    ctx.useCanvas(can);
    ctx.useColorScheme(getSkin());
    ctx.useFont(*fonts[FONT_NORMAL]);
    ctx.setSolidBackground();
    ctx.setColor(UIColor::tc_White);

    outTextF(ctx, x, y, wi, format(fmt, max));
    y += font_heights[FONT_NORMAL];
    if (max > 0) {
        outTextF(ctx, x, y, wi, format(_("Actual number: %d"), want));
    } else {
        outTextF(ctx, x, y, wi, string_t());
    }
    can.update(getExtent());
}

void
WPartCountInfo::getLayoutInfo(LayoutInfo& info)
{
    info.min_size = info.pref_size = font_sizes[FONT_NORMAL].scaledBy(15, 2);
    info.flags = li_FlexibleH;
}

void
WPartCountInfo::setPartsMax(int n)
{
    if (n != max) {
        max = n;
        want = max;
        drawWidget(false);
    }
}

void
WPartCountInfo::setPartsWanted(int n)
{
    if (n != want) {
        want = n;
        drawWidget(false);
    }
}

WPartCountGroup::WPartCountGroup(bool torps)
    : UIGroup(UIHBoxLayout::instance0),
      pci(torps),
      button_group(UIVBoxLayout::instance0),
      plus(0, "+", '+'),
      minus(0, "-", '-')
{
    init();
}

WPartCountGroup::~WPartCountGroup()
{ }

void
WPartCountGroup::init()
{
    add(pci);
    add(button_group);

    button_group.add(plus);
    button_group.add(minus);

    plus.addCall(this, &WPartCountGroup::onAdd);
    plus.setState(UIButton::bf_SmallSize, true);
    minus.addCall(this, &WPartCountGroup::onRemove);
    minus.setState(UIButton::bf_SmallSize, true);
}

void
WPartCountGroup::onAdd(int prefix)
{
    int n = getPartsWanted() + (prefix ? prefix : 1);
    if (n > getPartsMax())
        n = getPartsMax();
    setPartsWanted(n);
    handleCommand(UICommand(cm_CountChanged), *this);
}

void
WPartCountGroup::onRemove(int prefix)
{
    int n = getPartsWanted() - (prefix ? prefix : 1);
    if (n < 0)
        n = 0;
    setPartsWanted(n);
    handleCommand(UICommand(cm_CountChanged), *this);
}

void
WPartCountGroup::setPartsMax(int n)
{
    pci.setPartsMax(n);
    plus.setState(st_Disabled, n == 0);
    minus.setState(st_Disabled, n == 0);
}
