/**
  *  \file client/widgets/teamgrid.h
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_CLIENT_WIDGETS_TEAMGRID_H
#define PCC_V2_CLIENT_WIDGETS_TEAMGRID_H

#include "ui/ui.h"
#include "cpluslib/sigslot.h"
#include "game/playerset.h"
#include "ui/widgets/timer.h"

/** Team editor grid. Displays a grid of players and teams, with a
    marker at each player's team assignment, allowing the player to
    edit those settings. */
class WTeamGrid : public UIWidget {
    UITimer cursor_tick;

    int player;
    int team;
    GPlayerArray<int> player_teams;

    void set(int player, int team);

 public:
    WTeamGrid();
    ~WTeamGrid();

    void getLayoutInfo(LayoutInfo& info);
    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& event, bool second_pass);

    void setCursor(int player, int team);
    void moveCursor(int dp, int dt);

    void initFromGlobals();
    void saveToGlobals();

    int getCursorTeam() const;
    int getCursorPlayer() const;

    Signal0 sig_pos_changed;
};



inline int
WTeamGrid::getCursorTeam() const
{
    return team;
}

inline int
WTeamGrid::getCursorPlayer() const
{
    return player;
}

#endif
