/**
  *  \file int/if/basepred.h
  *  \brief Interpreter Game Interface: Starbase Prediction
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_INT_IF_BASEPRED_H
#define PCC_V2_INT_IF_BASEPRED_H

#include "int/predict.h"
#include "game/struct.h"
#include "game/planet.h"

/** Starbase Auto Task Predictor. This is used to predict a starbase's
    component storage for building. It therefore predicts ship building
    and recycling, plus fcode and mission.

    It does not attempt to predict time or minerals/cash. */
class WBaseTaskPredictor : public IntAutoTaskPredictor {
    GPlanet planet;
    void postBuildOrder(TBuildOrder order);
 public:
    WBaseTaskPredictor(const GPlanet& planet);
    void advanceTurn();
    bool predictInstruction(const string_t& name, IntArgBlock& args);
    GPlanet& getPlanet();
};

/** Get current state of planet. */
inline GPlanet&
WBaseTaskPredictor::getPlanet()
{
    return planet;
}

#endif
