/**
  *  \file reshack/painter.h
  *  \brief Resource Editor: Bitmap Editor
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */
#ifndef PCC_V2_RESHACK_PAINTER_H
#define PCC_V2_RESHACK_PAINTER_H

#include <vector>
#include "reshack/tools.h"
#include "cpluslib/smartptr.h"
#include "gfx/pixmap.h"
#include "reshack/colors.h"
#include "ui/ui.h"
#include "gfx/gfxcontext.h"

/** Bitmap editor. This is the basis for pixmap and font editing. */
class RHPainter : public UIWidget {
    Ptr<GfxPixmap> pixmap;
    Ptr<GfxPixmap> backup;
    RHTool*        tool;
    GfxContext     pixmap_context;

    std::vector<int> aux_lines[2];

    GfxPoint       last_pos;
    bool           mouse_is_down;

    int            scale;
    uint32_t       colors[3];

    ColorMode      color_mode;

    void handleMouse(GfxPoint pt, int btn);
    void moveOrigin(int dx, int dy);
    GfxPoint worldToScreen(GfxPoint pt);
    GfxPoint screenToWorld(GfxPoint pt);
 public:
    RHPainter(Ptr<GfxPixmap> pixmap, ColorMode color_mode);
    ~RHPainter();

    void drawContent(GfxCanvas& can);
    bool handleEvent(const UIEvent& e, bool second_pass);
    void getLayoutInfo(LayoutInfo& info);
    void onStateChange(int flags, bool enable);
    void addAuxLine(int n, bool onXAxis);
    void removeAuxLine(int n, bool onXAxis);

    void setTool(RHTool* tool);
    RHTool* getTool() const;

    void setZoom(int scale);
    int getZoom() const;

    void setColor(bool bg, uint32_t color);
    uint32_t getColor(bool bg) const;

    ColorMode getColorMode() const;

    Ptr<GfxPixmap> getPixmap() const;
    void setPixmap(Ptr<GfxPixmap> pix);

    GfxPoint getSize() const;
    void setSize(GfxPoint pt);
};

#endif
