/**
  *  \file ui/msgbox.cc
  *  \brief Implementation of Standard Message Boxes
  *
  *  (c) 2001-2011 Stefan Reuther <Streu@gmx.de>
  *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of file `COPYING' that comes with the
  *  source code.
  *
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
  */

#include "ui/msgbox.h"
#include "gfx/font.h"
#include "ui/util.h"
#include "ui/window.h"
#include "gfx/palette.h"
#include "ui/uiglobal.h"
#include "ui/layout.h"
#include "ui/commands.h"
#include "util/nls.h"
#include "ui/widgets/multilinestatic.h"
#include "ui/widgets/keytranslator.h"
#include "ui/widgets/button.h"

/******************************* WDialogBox ******************************/

UIMessageBox::UIMessageBox(string_t text, string_t title)
    : UIWindow(title, UIWindow::BLUE_WINDOW /* FIXME? */, COLOR_GRAY, 10),
      group(h.add(new UIGroup(UIHBoxLayout::instance5))),
      layout10(10),
      trans(h.add(new UIKeyTranslator()))
{
    setLayout(layout10);

    int width = fonts[FONT_TITLE]->getTextWidth(text);
    if (width < 200) {
        width = 200;
    } else if (width > 440) {
        /* The "400" is not a typo: we format it to a little shorter
           length to force more text to the second line, to make it
           look nicer. */
        width = getTextWidthFormatted(*fonts[FONT_TITLE], 400, text);
    }

    add(h.add(new UIMultilineStatic(FONT_TITLE, text, width)));
    add(group);
    add(trans);

    group.add(h.add(new UISpacer()));

    addKey(cm_Escape, SDLK_ESCAPE);
    addKey(cm_Enter,  SDLK_RETURN);
}

UIMessageBox&
UIMessageBox::addButton(int id, string_t btn, UIKey k)
{
    group.add(h.add(new UIButton(id, btn, k)).addStop());
    return *this;
}

UIMessageBox&
UIMessageBox::addKey(int id, UIKey k)
{
    trans.addStop(k, id);
    return *this;
}

int
UIMessageBox::run()
{
    group.add(h.add(new UISpacer()));
    pack();

    ui_root->centerWidget(*this);
    return ui_root->runModal(*this);
}

bool
UIMessageBox::doYesNoDialog()
{
    UIKeyString y(_("Yes")), n(_("No"));
    addButton(cm_Enter,  y.getString(), y.getKey());
    addButton(cm_Escape, n.getString(), n.getKey());
    addKey(cm_Enter, ' ');
    return run() == cm_Enter;
}

void
UIMessageBox::doOkDialog()
{
    addButton(cm_Enter, _("OK"), ' ');
    run();
}

/** Standard Message Box. A message box containing the specified text
    and title, and an "OK" button. The message box is modal. The text
    can contain '\n' to start new lines; it is automatically
    word-wrapped. */
void
messageBox(string_t text, string_t title)
{
    return UIMessageBox(text, title).doOkDialog();
}
